=== modified file 'drizzled/display.cc'
--- drizzled/display.cc	2010-12-24 16:11:53 +0000
+++ drizzled/display.cc	2010-12-27 19:18:58 +0000
@@ -76,11 +76,13 @@
 static const std::string CACHE_ITEM("CACHE_ITEM");
 static const std::string TYPE_HOLDER("TYPE_HOLDER");
 static const std::string PARAM_ITEM("PARAM_ITEM");
+static const std::string BOOLEAN_ITEM("BOOLEAN_ITEM");
 static const std::string DECIMAL_ITEM("DECIMAL_ITEM");
 
 static const std::string ITEM_CAST_SIGNED("ITEM_CAST_SIGNED");
 static const std::string ITEM_CAST_UNSIGNED("ITEM_CAST_UNSIGNED");
 static const std::string ITEM_CAST_BINARY("ITEM_CAST_BINARY");
+static const std::string ITEM_CAST_BOOLEAN("ITEM_CAST_BOOLEAN");
 static const std::string ITEM_CAST_DATE("ITEM_CAST_DATE");
 static const std::string ITEM_CAST_TIME("ITEM_CAST_TIME");
 static const std::string ITEM_CAST_DATETIME("ITEM_CAST_DATETIME");
@@ -100,6 +102,8 @@
     return ITEM_CAST_UNSIGNED;
   case drizzled::ITEM_CAST_BINARY:
     return ITEM_CAST_BINARY;
+  case drizzled::ITEM_CAST_BOOLEAN:
+    return ITEM_CAST_BOOLEAN;
   case drizzled::ITEM_CAST_DATE:
     return ITEM_CAST_DATE;
   case drizzled::ITEM_CAST_TIME:
@@ -189,6 +193,8 @@
     return TYPE_HOLDER;
   case drizzled::Item::PARAM_ITEM :
     return PARAM_ITEM;
+  case drizzled::Item::BOOLEAN_ITEM :
+    return BOOLEAN_ITEM;
   case drizzled::Item::DECIMAL_ITEM :
     return DECIMAL_ITEM;
   }

=== modified file 'drizzled/enum.h'
--- drizzled/enum.h	2010-12-24 16:11:53 +0000
+++ drizzled/enum.h	2010-12-27 19:18:58 +0000
@@ -1066,10 +1066,11 @@
   ER_INVALID_CAST_TO_SIGNED,
   ER_INVALID_CAST_TO_UNSIGNED,
   ER_INVALID_BOOLEAN_VALUE,
-
+  ER_INVALID_CAST_TO_BOOLEAN,
+  
   // Leave ER_INVALID_BOOLEAN_VALUE as LAST, and force people to use tags
   // instead of numbers in error messages in test.
-  ER_ERROR_LAST= ER_INVALID_BOOLEAN_VALUE
+  ER_ERROR_LAST= ER_INVALID_CAST_TO_BOOLEAN
 };
 
 enum drizzle_exit_codes {

=== modified file 'drizzled/error.cc'
--- drizzled/error.cc	2010-12-24 16:11:53 +0000
+++ drizzled/error.cc	2010-12-27 19:18:58 +0000
@@ -511,6 +511,7 @@
 
   // For BOOL type
   ADD_ERROR_MESSAGE(ER_INVALID_BOOLEAN_VALUE, N_("Received an invalid BOOLEAN value '%s'."));
+  ADD_ERROR_MESSAGE(ER_INVALID_CAST_TO_BOOLEAN, N_("Invalid cast to BOOLEAN: '%s'."));
 
   // Some old error values use the same strings as some new error values.
   ADD_ERROR_MESSAGE(EE_FILENOTFOUND, find(ER_FILE_NOT_FOUND));

=== modified file 'drizzled/field.h'
--- drizzled/field.h	2010-12-26 00:07:57 +0000
+++ drizzled/field.h	2010-12-27 19:18:58 +0000
@@ -239,6 +239,7 @@
   virtual Item_result result_type () const=0;
   virtual Item_result cmp_type () const { return result_type(); }
   virtual Item_result cast_to_int_type () const { return result_type(); }
+
   /**
      Check whether a field type can be partially indexed by a key.
 

=== added file 'drizzled/function/cast/boolean.cc'
--- drizzled/function/cast/boolean.cc	1970-01-01 00:00:00 +0000
+++ drizzled/function/cast/boolean.cc	2010-12-24 21:27:54 +0000
@@ -0,0 +1,203 @@
+/* - mode: c++ c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+#include "drizzled/function/cast/boolean.h"
+#include "drizzled/error.h"
+
+namespace drizzled {
+namespace function {
+namespace cast {
+
+void Boolean::print(String *str, enum_query_type query_type)
+{
+  str->append(STRING_WITH_LEN("cast("));
+  args[0]->print(str, query_type);
+  str->append(STRING_WITH_LEN(" as boolean)"));
+}
+
+drizzled::String *Boolean::val_str(drizzled::String *value)
+{
+  switch (args[0]->result_type())
+  {
+  case STRING_RESULT:
+    {
+      drizzled::String _res, *res;
+
+      if (not (res= args[0]->val_str(&_res)))
+      { 
+        null_value= true; 
+
+        break;
+      }
+      null_value= false; 
+
+      if (res->length() == 1)
+      {
+        switch (res->ptr()[0])
+        {
+        case 'y': case 'Y':
+        case 't': case 'T': // PG compatibility
+          return evaluate(true, value);
+
+        case 'n': case 'N':
+        case 'f': case 'F': // PG compatibility
+          return evaluate(false, value);
+
+        default:
+          break;
+        }
+      }
+      else if ((res->length() == 5) and (strcasecmp(res->ptr(), "FALSE") == 0))
+      {
+        return evaluate(false, value);
+      }
+      if ((res->length() == 4) and (strcasecmp(res->ptr(), "TRUE") == 0))
+      {
+        return evaluate(true, value);
+      }
+      else if ((res->length() == 5) and (strcasecmp(res->ptr(), "FALSE") == 0))
+      {
+        return evaluate(false, value);
+      }
+      else if ((res->length() == 3) and (strcasecmp(res->ptr(), "YES") == 0))
+      {
+        return evaluate(true, value);
+      }
+      else if ((res->length() == 2) and (strcasecmp(res->ptr(), "NO") == 0))
+      {
+        return evaluate(false, value);
+      }
+
+      my_error(ER_INVALID_CAST_TO_BOOLEAN, MYF(0), res->ptr());
+      return evaluate(false, value);
+    }
+
+  case REAL_RESULT:
+  case ROW_RESULT:
+  case DECIMAL_RESULT:
+  case INT_RESULT:
+    {
+      bool tmp= args[0]->val_bool();
+      null_value=args[0]->null_value;
+
+      return evaluate(tmp, value);
+    }
+  }
+
+  // We should never reach this
+  return evaluate(false, value);
+}
+
+String *Boolean::evaluate(const bool &result, String *val_buffer)
+{
+  const CHARSET_INFO * const cs= &my_charset_bin;
+  uint32_t mlength= (5) * cs->mbmaxlen;
+
+  val_buffer->alloc(mlength);
+  char *buffer=(char*) val_buffer->ptr();
+
+  if (result)
+  {
+    memcpy(buffer, "TRUE", 4);
+    val_buffer->length(4);
+  }
+  else
+  {
+    memcpy(buffer, "FALSE", 5);
+    val_buffer->length(5);
+  }
+
+  return val_buffer;
+}
+
+#if 0
+bool Boolean::val_bool()
+{
+  bool tmp= false;
+
+  switch (args[0]->result_type())
+  {
+  case STRING_RESULT:
+    {
+      drizzled::String _res, *res;
+
+      if (not (res= args[0]->val_str(&_res)))
+      { 
+        null_value= true; 
+
+        break;
+      }
+      null_value= false; 
+
+      if (res->length() == 1)
+      {
+        switch (res->ptr()[0])
+        {
+        case 'y': case 'Y':
+        case 't': case 'T': // PG compatibility
+          return true;
+
+        case 'n': case 'N':
+        case 'f': case 'F': // PG compatibility
+          return false;
+
+        default:
+          break;
+        }
+      }
+      else if ((res->length() == 5) and (strcasecmp(res->ptr(), "FALSE") == 0))
+      {
+        return false;
+      }
+      if ((res->length() == 4) and (strcasecmp(res->ptr(), "TRUE") == 0))
+      {
+        return true;
+      }
+      else if ((res->length() == 5) and (strcasecmp(res->ptr(), "FALSE") == 0))
+      {
+        return false;
+      }
+      else if ((res->length() == 3) and (strcasecmp(res->ptr(), "YES") == 0))
+      {
+        return true;
+      }
+      else if ((res->length() == 2) and (strcasecmp(res->ptr(), "NO") == 0))
+      {
+        return false;
+      }
+
+      break;
+    }
+
+  default:
+    tmp= args[0]->val_bool();
+    null_value=args[0]->null_value;
+  }
+
+  return tmp;
+}
+#endif
+
+
+} // namespace cast
+} // namespace function
+} // namespace drizzled

=== added file 'drizzled/function/cast/boolean.h'
--- drizzled/function/cast/boolean.h	1970-01-01 00:00:00 +0000
+++ drizzled/function/cast/boolean.h	2010-12-24 21:27:54 +0000
@@ -0,0 +1,55 @@
+/* - mode: c++ c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_FUNCTION_CAST_BOOLEAN_H
+#define DRIZZLED_FUNCTION_CAST_BOOLEAN_H
+
+#include "drizzled/function/str/strfunc.h"
+
+namespace drizzled {
+namespace function {
+namespace cast {
+
+class Boolean : public Item_str_func
+{
+public:
+  Boolean(Item *a) :
+    Item_str_func(a)
+  {}
+
+  drizzled::String *val_str(drizzled::String *value);
+
+  void fix_length_and_dec()
+  {
+    collation.set(&my_charset_bin);
+    max_length=args[0]->max_length;
+  }
+  virtual void print(String *str, enum_query_type query_type);
+  const char *func_name() const { return "cast_as_boolean"; }
+
+private:
+  String *evaluate(const bool &result, String *val_buffer);
+};
+
+} // namespace cast
+} // namespace function
+} // namespace drizzled
+
+#endif /* DRIZZLED_FUNCTION_CAST_BOOLEAN_H */

=== modified file 'drizzled/include.am'
--- drizzled/include.am	2010-12-26 02:04:09 +0000
+++ drizzled/include.am	2010-12-27 21:07:44 +0000
@@ -101,6 +101,7 @@
 			      drizzled/filesort_info.h \
 			      drizzled/foreign_key.h \
 			      drizzled/function/additive_op.h \
+			      drizzled/function/cast/boolean.h \
 			      drizzled/function/cast/signed.h \
 			      drizzled/function/cast/time.h \
 			      drizzled/function/cast/unsigned.h \
@@ -216,6 +217,7 @@
 			      drizzled/item/basic_constant.h \
 			      drizzled/item/bin_string.h \
 			      drizzled/item/blob.h \
+			      drizzled/item/boolean.h \
 			      drizzled/item/cache.h \
 			      drizzled/item/cache_decimal.h \
 			      drizzled/item/cache_int.h \
@@ -229,9 +231,11 @@
 			      drizzled/item/default_value.h \
 			      drizzled/item/direct_ref.h \
 			      drizzled/item/empty_string.h \
+			      drizzled/item/false.h \
 			      drizzled/item/field.h \
 			      drizzled/item/float.h \
 			      drizzled/item/func.h \
+			      drizzled/item/function/boolean.h \
 			      drizzled/item/hex_string.h \
 			      drizzled/item/ident.h \
 			      drizzled/item/insert_value.h \
@@ -248,6 +252,7 @@
 			      drizzled/item/string.h \
 			      drizzled/item/subselect.h \
 			      drizzled/item/sum.h \
+			      drizzled/item/true.h \
 			      drizzled/item/type_holder.h \
 			      drizzled/item/uint.h \
 			      drizzled/item_result.h \
@@ -532,6 +537,7 @@
 			   drizzled/filesort.cc \
 			   drizzled/foreign_key.cc \
 			   drizzled/function/additive_op.cc \
+			   drizzled/function/cast/boolean.cc \
 			   drizzled/function/cast/signed.cc \
 			   drizzled/function/cast/time.cc \
 			   drizzled/function/cast/unsigned.cc \
@@ -649,6 +655,7 @@
 			   drizzled/item/empty_string.cc \
 			   drizzled/item/field.cc \
 			   drizzled/item/float.cc \
+			   drizzled/item/function/boolean.cc \
 			   drizzled/item/hex_string.cc \
 			   drizzled/item/ident.cc \
 			   drizzled/item/insert_value.cc \

=== modified file 'drizzled/item.cc'
--- drizzled/item.cc	2010-12-27 19:16:17 +0000
+++ drizzled/item.cc	2010-12-28 04:57:17 +0000
@@ -1852,6 +1852,7 @@
   case drizzled::Item::PARAM_ITEM :
   case drizzled::Item::DECIMAL_ITEM :
   case drizzled::Item::FUNC_ITEM :
+  case drizzled::Item::BOOLEAN_ITEM :
     {
       output << "Item:(";
       output <<  item.full_name();

=== modified file 'drizzled/item.h'
--- drizzled/item.h	2010-12-26 00:07:57 +0000
+++ drizzled/item.h	2010-12-27 19:18:58 +0000
@@ -111,6 +111,7 @@
     ROW_ITEM, CACHE_ITEM,
     TYPE_HOLDER,
     PARAM_ITEM,
+    BOOLEAN_ITEM,
     DECIMAL_ITEM
   };
   enum traverse_order
@@ -177,6 +178,7 @@
    * Alloc & destruct is done as start of select using memory::sql_alloc
    */
   Item();
+
   /**
    * Constructor used by Item_field, Item_ref & aggregate (sum) functions.
    *
@@ -191,7 +193,7 @@
   virtual ~Item()
   {
 #ifdef EXTRA_DEBUG
-    name=0;
+    name= NULL;
 #endif
   }
 
@@ -374,6 +376,7 @@
    *   If value is not null null_value flag will be reset to false.
    */
   virtual String *val_str(String *str)=0;
+
   /**
    * Return decimal representation of item with fixed point.
    *

=== modified file 'drizzled/item/basic_constant.h'
--- drizzled/item/basic_constant.h	2010-12-18 04:43:40 +0000
+++ drizzled/item/basic_constant.h	2010-12-27 01:12:01 +0000
@@ -28,7 +28,10 @@
 class Item_basic_constant :public Item
 {
 public:
-  Item_basic_constant() : Item() {}
+  Item_basic_constant() :
+    Item()
+  {
+  }
 
   /* to prevent drop fixed flag (no need parent cleanup call) */
   void cleanup()

=== added file 'drizzled/item/boolean.h'
--- drizzled/item/boolean.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/boolean.h	2010-12-27 19:18:58 +0000
@@ -0,0 +1,108 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ITEM_BOOLEAN_H
+#define DRIZZLED_ITEM_BOOLEAN_H
+
+#include "drizzled/item/basic_constant.h"
+
+namespace drizzled
+{
+
+namespace item
+{
+
+class Boolean: public Item_basic_constant
+{
+  bool value;
+
+public:
+  Boolean(const char *str_arg, bool arg) :
+    Item_basic_constant(),
+    value(arg)
+  {
+    max_length= value ? 4 : 5;
+    fixed= true;
+    name= (const_cast<char *>(str_arg));
+  }
+
+  Boolean(bool arg) :
+    value(arg)
+  {
+    max_length= value ? 4 : 5;
+    fixed= true;
+
+    if (value)
+    {
+      name= const_cast<char *>("TRUE");
+    }
+    else
+    {
+      name= const_cast<char *>("FALSE");
+    }
+  }
+
+  enum Type type() const { return BOOLEAN_ITEM; }
+
+  virtual bool val_bool()
+  {
+    return value;
+  }
+
+  double val_real()
+  {
+    return value ? 1 : 0;
+  }
+
+  int64_t val_int() 
+  {
+    return value ? 1 : 0;
+  }
+
+  drizzled::String* val_str(drizzled::String *value_buffer)
+  {
+    value_buffer->realloc(5);
+
+    if (value)
+    {
+      value_buffer->append("TRUE");
+    }
+    else
+    {
+      value_buffer->append("FALSE");
+    }
+
+    return value_buffer;
+  }
+
+  type::Decimal* val_decimal(type::Decimal *dec)
+  {
+    (void)dec;
+    return 0;
+  }
+
+};
+
+} /* namespace item */
+} /* namespace drizzled */
+
+#include "drizzled/item/true.h"
+#include "drizzled/item/false.h"
+
+#endif /* DRIZZLED_ITEM_BOOLEAN_H */

=== modified file 'drizzled/item/cmpfunc.cc'
--- drizzled/item/cmpfunc.cc	2010-12-25 04:38:28 +0000
+++ drizzled/item/cmpfunc.cc	2010-12-27 21:05:56 +0000
@@ -1615,7 +1615,7 @@
 
 void Item_in_optimizer::cleanup()
 {
-  Item_bool_func::cleanup();
+  item::function::Boolean::cleanup();
   if (!save_cache)
     cache= 0;
   return;
@@ -3853,7 +3853,7 @@
 
 
 Item_cond::Item_cond(Session *session, Item_cond *item)
-  :Item_bool_func(session, item),
+  :item::function::Boolean(session, item),
    abort_on_null(item->abort_on_null),
    and_tables_cache(item->and_tables_cache)
 {
@@ -4886,7 +4886,7 @@
 }
 
 Item_equal::Item_equal(Item_field *f1, Item_field *f2)
-  : Item_bool_func(), const_item(0), eval_item(0), cond_false(0)
+  : item::function::Boolean(), const_item(0), eval_item(0), cond_false(0)
 {
   const_item_cache= 0;
   fields.push_back(f1);
@@ -4894,7 +4894,7 @@
 }
 
 Item_equal::Item_equal(Item *c, Item_field *f)
-  : Item_bool_func(), eval_item(0), cond_false(0)
+  : item::function::Boolean(), eval_item(0), cond_false(0)
 {
   const_item_cache= 0;
   fields.push_back(f);
@@ -4903,7 +4903,7 @@
 
 
 Item_equal::Item_equal(Item_equal *item_equal)
-  : Item_bool_func(), eval_item(0), cond_false(0)
+  : item::function::Boolean(), eval_item(0), cond_false(0)
 {
   const_item_cache= 0;
   List_iterator_fast<Item_field> li(item_equal->fields);

=== modified file 'drizzled/item/cmpfunc.h'
--- drizzled/item/cmpfunc.h	2010-12-25 01:27:46 +0000
+++ drizzled/item/cmpfunc.h	2010-12-27 21:05:56 +0000
@@ -34,6 +34,7 @@
 #include "drizzled/session.h"
 #include "drizzled/common.h"
 #include "drizzled/qsort_cmp.h"
+#include "drizzled/item/function/boolean.h"
 
 namespace drizzled
 {
@@ -125,25 +126,13 @@
   friend class Item_func;
 };
 
-class Item_bool_func :public Item_int_func
-{
-public:
-  Item_bool_func() :Item_int_func() {}
-  Item_bool_func(Item *a) :Item_int_func(a) {}
-  Item_bool_func(Item *a,Item *b) :Item_int_func(a,b) {}
-  Item_bool_func(Session *session, Item_bool_func *item) :Item_int_func(session, item) {}
-  bool is_bool_func() { return 1; }
-  void fix_length_and_dec() { decimals=0; max_length=1; }
-  uint32_t decimal_precision() const { return 1; }
-};
-
 
 /**
   Abstract Item class, to represent <code>X IS [NOT] (TRUE | FALSE)</code>
   boolean predicates.
 */
 
-class Item_func_truth : public Item_bool_func
+class Item_func_truth : public item::function::Boolean
 {
 public:
   virtual bool val_bool();
@@ -153,7 +142,7 @@
 
 protected:
   Item_func_truth(Item *a, bool a_value, bool a_affirmative)
-  : Item_bool_func(a), value(a_value), affirmative(a_affirmative)
+  : item::function::Boolean(a), value(a_value), affirmative(a_affirmative)
   {}
 
   ~Item_func_truth()
@@ -242,7 +231,7 @@
     placed into a separate class called 'Item_in_optimizer'.
 */
 
-class Item_in_optimizer: public Item_bool_func
+class Item_in_optimizer: public item::function::Boolean
 {
 protected:
   Item_cache *cache;
@@ -256,7 +245,7 @@
   bool result_for_null_param;
 public:
   Item_in_optimizer(Item *a, Item_in_subselect *b):
-    Item_bool_func(a, reinterpret_cast<Item *>(b)), cache(0),
+    item::function::Boolean(a, reinterpret_cast<Item *>(b)), cache(0),
     save_cache(0), result_for_null_param(UNKNOWN)
   { with_subselect= true; }
   bool fix_fields(Session *, Item **);
@@ -388,10 +377,10 @@
   { return true; }
 };
 
-class Item_func_not :public Item_bool_func
+class Item_func_not :public item::function::Boolean
 {
 public:
-  Item_func_not(Item *a) :Item_bool_func(a) {}
+  Item_func_not(Item *a) :item::function::Boolean(a) {}
   int64_t val_int();
   enum Functype functype() const { return NOT_FUNC; }
   const char *func_name() const { return "not"; }
@@ -430,11 +419,11 @@
    - To wrap condition that is pushed down into subquery
 */
 
-class Item_func_trig_cond: public Item_bool_func
+class Item_func_trig_cond: public item::function::Boolean
 {
   bool *trig_var;
 public:
-  Item_func_trig_cond(Item *a, bool *f) : Item_bool_func(a) { trig_var= f; }
+  Item_func_trig_cond(Item *a, bool *f) : item::function::Boolean(a) { trig_var= f; }
   int64_t val_int() { return *trig_var ? args[0]->val_int() : 1; }
   enum Functype functype() const { return TRIG_COND_FUNC; };
   const char *func_name() const { return "trigcond"; };
@@ -1286,12 +1275,12 @@
 
 /* Functions used by where clause */
 
-class Item_func_isnull :public Item_bool_func
+class Item_func_isnull :public item::function::Boolean
 {
 protected:
   int64_t cached_value;
 public:
-  Item_func_isnull(Item *a) :Item_bool_func(a) {}
+  Item_func_isnull(Item *a) :item::function::Boolean(a) {}
   int64_t val_int();
   enum Functype functype() const { return ISNULL_FUNC; }
   void fix_length_and_dec()
@@ -1353,11 +1342,11 @@
 };
 
 
-class Item_func_isnotnull :public Item_bool_func
+class Item_func_isnotnull :public item::function::Boolean
 {
   bool abort_on_null;
 public:
-  Item_func_isnotnull(Item *a) :Item_bool_func(a), abort_on_null(0) {}
+  Item_func_isnotnull(Item *a) :item::function::Boolean(a), abort_on_null(0) {}
   int64_t val_int();
   enum Functype functype() const { return ISNOTNULL_FUNC; }
   void fix_length_and_dec()
@@ -1417,7 +1406,7 @@
 
 typedef class Item COND;
 
-class Item_cond :public Item_bool_func
+class Item_cond :public item::function::Boolean
 {
 protected:
   List<Item> list;
@@ -1429,17 +1418,17 @@
   using Item::split_sum_func;
 
   /* Item_cond() is only used to create top level items */
-  Item_cond(): Item_bool_func(), abort_on_null(1)
+  Item_cond(): item::function::Boolean(), abort_on_null(1)
   { const_item_cache=0; }
   Item_cond(Item *i1,Item *i2)
-    :Item_bool_func(), abort_on_null(0)
+    :item::function::Boolean(), abort_on_null(0)
   {
     list.push_back(i1);
     list.push_back(i2);
   }
   Item_cond(Session *session, Item_cond *item);
   Item_cond(List<Item> &nlist)
-    :Item_bool_func(), list(nlist), abort_on_null(0) {}
+    :item::function::Boolean(), list(nlist), abort_on_null(0) {}
   bool add(Item *item) { return list.push_back(item); }
   bool add_at_head(Item *item) { return list.push_front(item); }
   void add_at_head(List<Item> *nlist) { list.prepand(nlist); }
@@ -1543,16 +1532,23 @@
   object represents f1=f2= ...=fn to the projection of known fields fi1=...=fik.
 */
 
-class Item_equal: public Item_bool_func
+class Item_equal: public item::function::Boolean
 {
   List<Item_field> fields; /* list of equal field items                    */
   Item *const_item;        /* optional constant item equal to fields items */
   cmp_item *eval_item;
   bool cond_false;
+
 public:
-  inline Item_equal()
-    : Item_bool_func(), const_item(0), eval_item(0), cond_false(0)
-  { const_item_cache=0 ;}
+  inline Item_equal() :
+    item::function::Boolean(),
+    const_item(0),
+    eval_item(0),
+    cond_false(0)
+  {
+    const_item_cache=0;
+  }
+
   Item_equal(Item_field *f1, Item_field *f2);
   Item_equal(Item *c, Item_field *f);
   Item_equal(Item_equal *item_equal);

=== modified file 'drizzled/item/create.cc'
--- drizzled/item/create.cc	2010-12-25 00:28:49 +0000
+++ drizzled/item/create.cc	2010-12-27 19:18:58 +0000
@@ -83,6 +83,7 @@
 #include <drizzled/function/math/tan.h>
 #include <drizzled/function/units.h>
 
+#include "drizzled/function/cast/boolean.h"
 #include "drizzled/function/cast/signed.h"
 #include "drizzled/function/cast/time.h"
 #include "drizzled/function/cast/unsigned.h"
@@ -2104,6 +2105,10 @@
     res= new (session->mem_root) Item_func_binary(a);
     break;
 
+  case ITEM_CAST_BOOLEAN:
+    res= new (session->mem_root) function::cast::Boolean(a);
+    break;
+
   case ITEM_CAST_TIME:
     res= new (session->mem_root) function::cast::Time(a);
     break;

=== added file 'drizzled/item/false.h'
--- drizzled/item/false.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/false.h	2010-12-27 01:12:01 +0000
@@ -0,0 +1,50 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ITEM_FALSE_H
+#define DRIZZLED_ITEM_FALSE_H
+
+#include "drizzled/item/boolean.h"
+
+namespace drizzled
+{
+
+namespace item
+{
+
+class Boolean;
+
+class False: public Boolean
+{
+public:
+  False() :
+    Boolean(false)
+  {
+  }
+
+  False(const char *str_arg) :
+    Boolean(str_arg, false)
+  {
+  }
+};
+
+} /* namespace item */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_ITEM_FALSE_H */

=== modified file 'drizzled/item/func.h'
--- drizzled/item/func.h	2010-12-24 00:35:17 +0000
+++ drizzled/item/func.h	2010-12-27 19:18:58 +0000
@@ -49,6 +49,7 @@
   ITEM_CAST_TIME,
   ITEM_CAST_DATETIME,
   ITEM_CAST_CHAR,
+  ITEM_CAST_BOOLEAN,
   ITEM_CAST_DECIMAL
 };
 

=== added directory 'drizzled/item/function'
=== added file 'drizzled/item/function/boolean.cc'
--- drizzled/item/function/boolean.cc	1970-01-01 00:00:00 +0000
+++ drizzled/item/function/boolean.cc	2010-12-27 20:20:52 +0000
@@ -0,0 +1,35 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#include "config.h"
+
+namespace drizzled
+{
+
+namespace item
+{
+
+namespace function
+{
+
+
+} /* namespace function */
+} /* namespace item */
+} /* namespace drizzled */

=== added file 'drizzled/item/function/boolean.h'
--- drizzled/item/function/boolean.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/function/boolean.h	2010-12-27 20:20:52 +0000
@@ -0,0 +1,77 @@
+/* - mode: c; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+
+#ifndef DRIZZLED_ITEM_FUNCTION_BOOLEAN_H
+#define DRIZZLED_ITEM_FUNCTION_BOOLEAN_H
+
+#include "drizzled/function/math/int.h"
+
+namespace drizzled
+{
+
+namespace item
+{
+
+namespace function
+{
+
+class Boolean :public Item_int_func
+{
+public:
+  Boolean() :
+    Item_int_func()
+  {}
+
+  Boolean(Item *a) :
+    Item_int_func(a)
+  {}
+
+  Boolean(Item *a,Item *b) :
+    Item_int_func(a,b)
+  {}
+
+  Boolean(Session *session, Boolean *item) :
+    Item_int_func(session, item)
+  {}
+
+  bool is_bool_func()
+  {
+    return true;
+  }
+
+  void fix_length_and_dec()
+  {
+    decimals= 0;
+    max_length= 1;
+  }
+
+  uint32_t decimal_precision() const
+  {
+    return 1;
+  }
+};
+
+} /* namespace function */
+} /* namespace item */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_ITEM_FUNCTION_BOOLEAN_H */

=== added file 'drizzled/item/true.h'
--- drizzled/item/true.h	1970-01-01 00:00:00 +0000
+++ drizzled/item/true.h	2010-12-27 01:12:01 +0000
@@ -0,0 +1,49 @@
+/* -*- mode: c++; c-basic-offset: 2; indent-tabs-mode: nil; -*-
+ *  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
+ *
+ *  Copyright (C) 2010 Brian Aker
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; version 2 of the License.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ */
+
+#ifndef DRIZZLED_ITEM_TRUE_H
+#define DRIZZLED_ITEM_TRUE_H
+
+namespace drizzled
+{
+
+namespace item
+{
+
+class Boolean;
+
+class True: public Boolean
+{
+public:
+  True() :
+    Boolean(true)
+  {
+  }
+
+  True(const char *str_arg) :
+    Boolean(str_arg, true)
+  {
+  }
+
+};
+
+} /* namespace item */
+} /* namespace drizzled */
+
+#endif /* DRIZZLED_ITEM_TRUE_H */

=== modified file 'drizzled/parser.h'
--- drizzled/parser.h	2010-10-23 21:00:18 +0000
+++ drizzled/parser.h	2010-12-27 01:12:01 +0000
@@ -105,4 +105,6 @@
 #include "drizzled/charset.h"
 #include "drizzled/internal/m_string.h"
 
+#include "drizzled/item/boolean.h"
+
 #endif /* DRIZZLED_PARSER_H */

=== modified file 'drizzled/sql_string.h'
--- drizzled/sql_string.h	2010-12-24 05:50:22 +0000
+++ drizzled/sql_string.h	2010-12-27 01:12:01 +0000
@@ -217,13 +217,13 @@
       char *new_ptr;
       if (!(new_ptr= reinterpret_cast<char*>(::realloc(Ptr,arg_length))))
       {
-	Alloced_length = 0;
-	real_alloc(arg_length);
+        Alloced_length = 0;
+        real_alloc(arg_length);
       }
       else
       {
-	Ptr=new_ptr;
-	Alloced_length=arg_length;
+        Ptr=new_ptr;
+        Alloced_length=arg_length;
       }
     }
   }
@@ -272,7 +272,7 @@
     else
     {
       if (realloc(str_length+1))
-	return 1;
+        return 1;
       Ptr[str_length++]=chr;
     }
     return 0;

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2010-12-24 20:54:13 +0000
+++ drizzled/sql_yacc.yy	2010-12-27 20:18:43 +0000
@@ -82,6 +82,13 @@
 class Item;
 class Item_num;
 
+namespace item
+{
+class Boolean;
+class True;
+class False;
+}
+
 
 static bool check_reserved_words(LEX_STRING *name)
 {
@@ -3649,6 +3656,8 @@
 cast_type:
           BINARY opt_len
           { $$=ITEM_CAST_CHAR; Lex->charset= &my_charset_bin; Lex->dec= 0; }
+        | BOOLEAN_SYM
+          { $$=ITEM_CAST_BOOLEAN; Lex->charset= &my_charset_bin; Lex->dec= 0; }
         | SIGNED_SYM
           { $$=ITEM_CAST_SIGNED; Lex->charset= NULL; Lex->dec=Lex->length= (char*)0; }
         | SIGNED_SYM INT_SYM
@@ -5940,8 +5949,8 @@
             $$ = new Item_null();
             YYSession->m_lip->next_state=MY_LEX_OPERATOR_OR_IDENT;
           }
-        | FALSE_SYM { $$= new Item_int((char*) "FALSE",0,1); }
-        | TRUE_SYM { $$= new Item_int((char*) "TRUE",1,1); }
+        | FALSE_SYM { $$= new drizzled::item::False(); }
+        | TRUE_SYM { $$= new drizzled::item::True(); }
         | HEX_NUM { $$ = new Item_hex_string($1.str, $1.length);}
         | BIN_NUM { $$= new Item_bin_string($1.str, $1.length); }
         | DATE_SYM text_literal { $$ = $2; }

=== modified file 'plugin/debug/module.cc'
--- plugin/debug/module.cc	2010-12-16 01:48:53 +0000
+++ plugin/debug/module.cc	2010-12-27 20:20:52 +0000
@@ -41,16 +41,17 @@
 #include <drizzled/util/backtrace.h>
 #include <drizzled/function/func.h>
 #include <drizzled/item/cmpfunc.h>
+#include <drizzled/item/function/boolean.h>
 
 using namespace drizzled;
 
 namespace debug {
 
-class Assert :public Item_bool_func
+class Assert :public item::function::Boolean
 {
 public:
   Assert() :
-    Item_bool_func()
+    item::function::Boolean()
   {
     unsigned_flag= true;
   }
@@ -60,8 +61,8 @@
 
   bool val_bool()
   {
-    drizzled::String _res;
-    drizzled::String *res= args[0]->val_str(&_res);
+    String _res;
+    String *res= args[0]->val_str(&_res);
 
     null_value= false;
 
@@ -85,11 +86,11 @@
   }
 };
 
-class Backtrace :public Item_bool_func
+class Backtrace :public item::function::Boolean
 {
 public:
   Backtrace() :
-    Item_bool_func()
+    item::function::Boolean()
   {
     unsigned_flag= true;
   }
@@ -99,7 +100,7 @@
 
   bool val_bool()
   {
-    drizzled::util::custom_backtrace();
+    util::custom_backtrace();
     return true;
   }
 
@@ -109,11 +110,11 @@
   }
 };
 
-class Crash :public Item_bool_func
+class Crash :public item::function::Boolean
 {
 public:
   Crash() :
-    Item_bool_func()
+    item::function::Boolean()
   { }
 
   const char *func_name() const { return "crash"; }

=== modified file 'plugin/debug/plugin.ini'
--- plugin/debug/plugin.ini	2010-12-16 01:48:53 +0000
+++ plugin/debug/plugin.ini	2010-12-27 20:20:52 +0000
@@ -1,6 +1,7 @@
 [plugin]
 title=Kernel debugger utilities.
 description=crash(), assert(), and additional developer style tools.
-load_by_default=no
+load_by_default=yes
+static=yes
 sources=
   module.cc

=== modified file 'plugin/filesystem_engine/tests/r/basic_update.result'
--- plugin/filesystem_engine/tests/r/basic_update.result	2010-09-23 01:53:13 +0000
+++ plugin/filesystem_engine/tests/r/basic_update.result	2010-12-27 22:56:55 +0000
@@ -12,4 +12,7 @@
 111	aaa
 333	ccc
 DELETE FROM t1 WHERE a!=111;
+SELECT * FROM t1;
+a	b
+111	aaa
 DROP TABLE t1;

=== modified file 'plugin/filesystem_engine/tests/t/basic_update.test'
--- plugin/filesystem_engine/tests/t/basic_update.test	2010-09-23 01:53:13 +0000
+++ plugin/filesystem_engine/tests/t/basic_update.test	2010-12-27 22:56:55 +0000
@@ -15,4 +15,6 @@
 
 DELETE FROM t1 WHERE a!=111;
 
+SELECT * FROM t1;
+
 DROP TABLE t1;

=== modified file 'plugin/string_functions/regex.h'
--- plugin/string_functions/regex.h	2010-12-07 21:33:25 +0000
+++ plugin/string_functions/regex.h	2010-12-27 20:20:52 +0000
@@ -21,7 +21,7 @@
 #ifndef PLUGIN_STRING_FUNCTIONS_REGEX_H
 #define PLUGIN_STRING_FUNCTIONS_REGEX_H
 
-#include <drizzled/item/cmpfunc.h>
+#include <drizzled/item/function/boolean.h>
 #include <boost/regex.hpp>
 
 namespace drizzled
@@ -29,7 +29,7 @@
 namespace string_functions
 {
 
-class Regex :public Item_bool_func
+class Regex :public drizzled::item::function::Boolean
 {
   bool is_negative;
   boost::regex re;

=== modified file 'plugin/utility_functions/execute.h'
--- plugin/utility_functions/execute.h	2010-12-08 03:38:36 +0000
+++ plugin/utility_functions/execute.h	2010-12-27 20:20:52 +0000
@@ -22,7 +22,7 @@
 #ifndef PLUGIN_UTILITY_FUNCTIONS_EXECUTE_H
 #define PLUGIN_UTILITY_FUNCTIONS_EXECUTE_H
 
-#include <drizzled/item/cmpfunc.h>
+#include <drizzled/item/function/boolean.h>
 #include <drizzled/execute.h>
 #include <iostream>
 
@@ -32,14 +32,14 @@
 namespace utility_functions
 {
 
-class Execute :public Item_bool_func
+class Execute :public drizzled::item::function::Boolean
 {
   drizzled::String _res;
   drizzled::Execute execute;
 
 public:
   Execute() :
-    Item_bool_func(),
+    drizzled::item::function::Boolean(),
     execute(getSession(), false)
   {
     unsigned_flag= true;

=== added file 'tests/suite/cast/r/boolean.result'
--- tests/suite/cast/r/boolean.result	1970-01-01 00:00:00 +0000
+++ tests/suite/cast/r/boolean.result	2010-12-27 19:18:58 +0000
@@ -0,0 +1,50 @@
+SELECT CAST(1 AS BOOLEAN);
+CAST(1 AS BOOLEAN)
+TRUE
+SELECT CAST(2 AS BOOLEAN);
+CAST(2 AS BOOLEAN)
+TRUE
+SELECT CAST(0 AS BOOLEAN);
+CAST(0 AS BOOLEAN)
+FALSE
+SELECT CAST(-0 AS BOOLEAN);
+CAST(-0 AS BOOLEAN)
+FALSE
+SELECT CAST(-1 AS BOOLEAN);
+CAST(-1 AS BOOLEAN)
+TRUE
+SELECT CAST(0.1 AS BOOLEAN);
+CAST(0.1 AS BOOLEAN)
+TRUE
+SELECT CAST(0.0 AS BOOLEAN);
+CAST(0.0 AS BOOLEAN)
+FALSE
+SELECT CAST(3.0 AS BOOLEAN);
+CAST(3.0 AS BOOLEAN)
+TRUE
+SELECT CAST("TRUE" AS BOOLEAN);
+CAST("TRUE" AS BOOLEAN)
+TRUE
+SELECT CAST("FALSE" AS BOOLEAN);
+CAST("FALSE" AS BOOLEAN)
+FALSE
+SELECT CAST("FRED" AS BOOLEAN);
+ERROR HY000: Invalid cast to BOOLEAN: 'FRED'.
+SELECT CAST(FALSE AS BOOLEAN);
+CAST(FALSE AS BOOLEAN)
+FALSE
+SELECT CAST(TRUE AS BOOLEAN);
+CAST(TRUE AS BOOLEAN)
+TRUE
+SELECT CAST(TRUE AS BOOLEAN) IS TRUE;
+CAST(TRUE AS BOOLEAN) IS TRUE
+0
+SELECT CAST(TRUE AS BOOLEAN) IS FALSE;
+CAST(TRUE AS BOOLEAN) IS FALSE
+1
+SELECT CAST(FALSE AS BOOLEAN) IS TRUE;
+CAST(FALSE AS BOOLEAN) IS TRUE
+0
+SELECT CAST(FALSE AS BOOLEAN) IS FALSE;
+CAST(FALSE AS BOOLEAN) IS FALSE
+1

=== added file 'tests/suite/cast/t/boolean.test'
--- tests/suite/cast/t/boolean.test	1970-01-01 00:00:00 +0000
+++ tests/suite/cast/t/boolean.test	2010-12-27 19:18:58 +0000
@@ -0,0 +1,25 @@
+SELECT CAST(1 AS BOOLEAN);
+SELECT CAST(2 AS BOOLEAN);
+SELECT CAST(0 AS BOOLEAN);
+SELECT CAST(-0 AS BOOLEAN);
+SELECT CAST(-1 AS BOOLEAN);
+
+SELECT CAST(0.1 AS BOOLEAN);
+SELECT CAST(0.0 AS BOOLEAN);
+SELECT CAST(3.0 AS BOOLEAN);
+
+SELECT CAST("TRUE" AS BOOLEAN);
+SELECT CAST("FALSE" AS BOOLEAN);
+
+--error ER_INVALID_CAST_TO_BOOLEAN
+SELECT CAST("FRED" AS BOOLEAN);
+
+SELECT CAST(FALSE AS BOOLEAN);
+SELECT CAST(TRUE AS BOOLEAN);
+
+SELECT CAST(TRUE AS BOOLEAN) IS TRUE;
+SELECT CAST(TRUE AS BOOLEAN) IS FALSE;
+
+SELECT CAST(FALSE AS BOOLEAN) IS TRUE;
+SELECT CAST(FALSE AS BOOLEAN) IS FALSE;
+

